/*******************************************************************************

     Copyright (c) 2014-2017, Analog Devices, Inc.  All rights reserved.

     Redistribution and use in source and binary forms, with or without
     modification, are permitted (subject to the limitations in the
     disclaimer below) provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.

     * Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in the
       documentation and/or other materials provided with the
       distribution.

     * Neither the name of Analog Devices, Inc.  nor the names of its
       contributors may be used to endorse or promote products derived
       from this software without specific prior written permission.

     NO EXPRESS OR IMPLIED LICENSES TO ANY PARTY'S PATENT RIGHTS ARE
     GRANTED BY THIS LICENSE.  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT
     HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
     WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
     MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
     LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
     CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
     SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
     BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
     WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
     OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
     IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


*******************************************************************************/


/*******************************************************************************

    File name:    sc5xx_init.h
    Purpose:      Initialize memory configuration for ADSP-SC5xx or ADSP-215xx.
    Notes:

*******************************************************************************/

#ifndef SC5XX_INIT_H
#define SC5XX_INIT_H

#if !defined(__ADSPSC589_FAMILY__) && !defined(__ADSPSC573_FAMILY__)
  #error expected to be built for an ADSP-SC589 or ADSP-SC573 family part
#endif

/*
 * Dynamic Memory Controllers (DMC) configuration.
 *
 * Parts with 2 DMCs are: ADSP-SC587 ADSP-SC589 ADSP-21587
 * Parts with 1 DMCs are: ADSP-SC584 ADSP-SC583 ADSP-SC582
 *                        ADSP-21584 ADSP-21583
 *                        ADSP-SC573 ADSP-SC572 ADSP-21573
 * Parts with 0 DMCs are: ADSP-SC571 ADSP-SC570 ADSP-21571
 *
 * DMC memory initialization is activated by default below for parts with DMCs.
 * To deactivate one or both DMCs define the appropriate CONFIG_DMC0 or
 * CONFIG_DMC1 macro to to 0. This can be done by modifying the code below or
 * by defining them in the build settings.
 *
 * When building for a parts with an EZ-KIT the default EZ-KIT configuration is
 * used if CONFIG_DMC0 and CONFIG_DMC1 are not defined. Supported EZ-KITS are:
 *
 * ADSP-SC589             - Two 2Gb DDR3 Micron MT41K128M16JT chips.
 * ADSP-SC584 /ADSP-SC573 - 2Gb DDR2 Micron MT47H128M16 chip
 *
 * If using using custom hardware that uses the same DDR as one of these
 * EZ-KITS you can define one of the CONFIG_BOARD_MATCHES macros seen below.
 */

/* enumerate supported memory types */
#define DMC_NONE                      (0)  /* DMC_NONE must be 0 */
#define Micron_2Gb_DDR2_MT47H128M16   (1)
#define Micron_2Gb_DDR3_MT41K128M16JT (2)
#define Micron_2Gb_LPDDR_MT46H128M16LFDD (3)

/* config.h can be used to define the various CONFIG_ configuration macros */
#include "config.h"


/*
 * CGU configuration support is enabled by default and can't be disabled.
 */

#define MHZTOHZ       (1000000u)
#define CLKIN0        (25u * MHZTOHZ)  /* PLL input clock's frequency. */
#define CLKIN1        (25u * MHZTOHZ)  /* CLKIN1 is used for CGU1 even though
                                          CLKIN0 could be used.  */
/* Macros for CGU0 and CGU1 */
#define CGU_DEV_0     (0uL)
#define CGU_DEV_1     (1uL)

/* Power settings.
** The macros below are settings to configure the core clock (CCLK) and
** DDR interface clock (DCLK) frequencies.
**
** The equation for these frequencies are:
**
**   CCLK frequency = (CLKIN frequency / (DF+1)) * MSEL / CSEL
**   DCLK frequency = (CLKIN frequency / (DF+1)) * MSEL / DSEL
**
** By default, use CGU0 to configure CCLK to match the maximum DCLK. For DDR2,
** the maximum is 400MHz and for DDR3 it's 450MHz. CGU1 is not used is not
** used by default.
**
** The default CCLK and DCLK can be overridden by defining the macros
** CONFIG_CORE_CLOCK_SPEED and CONFIG_DDR_CLOCK_SPEED respectively.
**
** NOTE: If CONFIG_CORE_CLOCK_SPEED and CONFIG_DDR_CLOCK_SPEED have different
** values, both CGU0 and CGU1 will be required. CGU0 will be used to configure
** CCLK and CGU1 will be used to configure DCLK.
*/

/* If CLOCK_SPEED_500MHZ is defined for ADSP-SC58x or ADSP-2158x, override
** CONFIG_CORE_CLOCK_SPEED. DCLK isn't configured by CLOCK_SPEED_500MHZ being defined.
*/
#if defined(__ADSPSC589_FAMILY__) && defined(CLOCK_SPEED_500MHZ)
# define CONFIG_CORE_CLOCK_SPEED (500u * MHZTOHZ)
#endif


#  define CONFIG_DDR_CLOCK_SPEED (200u * MHZTOHZ)

/* CLKIN Multiplier Select. */
#define MSEL_CGU_DEV_0    (CONFIG_CORE_CLOCK_SPEED / CLKIN0)
#if CONFIG_CORE_CLOCK_SPEED != CONFIG_DDR_CLOCK_SPEED
# define MSEL_CGU_DEV_1   (CONFIG_DDR_CLOCK_SPEED / CLKIN1)
#endif

/* Common values for each CGU. */
#define DF_DEFAULT        (0x0u) /* CLKIN divide by 2 unset */
#define CSEL_DEFAULT      (0x1u) /* CCLK Divisor */
#define SYSSEL_DEFAULT    (0x2u) /* SYSCLK Divisor */
#define S0SEL_DEFAULT     (0x2u) /* SCLK0 Divisor */
#define S1SEL_DEFAULT     (0x2u) /* SCLK1 Divisor */
#define DSEL_DEFAULT      (0x2u) /* DCLK Divisor */

/*
 * CONFIG_SMPU controls whether System Memory Protection Unit (SMPU) instances
 * are initialized to disable accesses to :
 *   SMC
 *   PCIe (for ADSP-SC58x and ADSP-2158x parts with PCIE)
 *   DMC0 (if !CONFIG_DMC0)
 *   DMC1 (if !CONFIG_DMC1)
 */
#if !defined(CONFIG_SMPU)
  #define CONFIG_SMPU 1 /* done by default */
#endif

/*
 * UNUSED_SPI_FLASH controls whether the 20000018 silicon anomaly SPI flash
 * workaround is included or not. This part of the workaround should most
 * ideally be done in the application code when and if it is known that the
 * SPI flash is not required.
 */
#if !defined(UNUSED_SPI_FLASH)
  /* not done by default as there is SPI FLASH on EZ-Boards */
  #define UNUSED_SPI_FLASH 0
#endif

#endif /* SC5XX_INIT_H */

#define DMC_CTL_VALUE 		0x00002406
#define DMC_CFG_VALUE 		0x00000522
#define DMC_TR0_VALUE 		0x20B08323
#define DMC_TR1_VALUE 		0x200F0618
#define DMC_TR2_VALUE 		0x00123000
#define DMC_MR0_VALUE		0x00000032
#define DMC_MR1_VALUE 		0
#define DMC_MR2_VALUE 		0x20
#define DMC_PADCTL2_VALUE 	0
#define DMC_CPHYCTL_VALUE   0x00000000
#define DMC0_DATA_CALIB_ADD 0x80000000
